Index: branches/eam_branches/20091201/psModules/src/imcombine/pmSubtraction.c
===================================================================
--- branches/eam_branches/20091201/psModules/src/imcombine/pmSubtraction.c	(revision 26578)
+++ branches/eam_branches/20091201/psModules/src/imcombine/pmSubtraction.c	(revision 26579)
@@ -64,9 +64,9 @@
 }
 
-// Contribute to an image of the solved kernel component for ISIS
-static void solvedKernelISIS(psKernel *kernel, // Kernel, updated
-                             const pmSubtractionKernels *kernels, // Kernel basis functions
-                             float value,                         // Normalisation value for basis function
-                             int index                  // Index of basis function of interest
+// Contribute to an image of the solved kernel component using the preCalculated image
+static void solvedKernelPreCalc(psKernel *kernel, // Kernel, updated
+				const pmSubtractionKernels *kernels, // Kernel basis functions
+				float value,                         // Normalisation value for basis function
+				int index                  // Index of basis function of interest
     )
 {
@@ -152,5 +152,5 @@
           case PM_SUBTRACTION_KERNEL_GUNK: {
               if (i < kernels->inner) {
-                  solvedKernelISIS(kernel, kernels, value, i);
+                  solvedKernelPreCalc(kernel, kernels, value, i);
               } else {
                   // Using delta function
@@ -162,15 +162,10 @@
               break;
           }
-          case PM_SUBTRACTION_KERNEL_ISIS: {
-              solvedKernelISIS(kernel, kernels, value, i);
-              break;
-          }
-          case PM_SUBTRACTION_KERNEL_HERM: {
-              solvedKernelISIS(kernel, kernels, value, i);
-              break;
-          }
+          case PM_SUBTRACTION_KERNEL_ISIS: 
+          case PM_SUBTRACTION_KERNEL_ISIS_RADIAL: 
+          case PM_SUBTRACTION_KERNEL_HERM:               
           case PM_SUBTRACTION_KERNEL_DECONV_HERM: {
-              solvedKernelISIS(kernel, kernels, value, i);
-              break;
+	      solvedKernelPreCalc(kernel, kernels, value, i);              
+	      break;
           }
           case PM_SUBTRACTION_KERNEL_RINGS: {
@@ -463,9 +458,9 @@
 #endif
 
-// Convolve a stamp using an ISIS kernel basis function
-static psKernel *convolveStampISIS(const psKernel *image, // Image to convolve
-                                   const pmSubtractionKernels *kernels, // Kernel basis functions
-                                   int index,                            // Index of basis function of interest
-                                   int footprint                         // Half-size of stamp
+// Convolve a stamp using a pre-calculated kernel basis function
+static psKernel *convolveStampPreCalc(const psKernel *image, // Image to convolve
+				      const pmSubtractionKernels *kernels, // Kernel basis functions
+				      int index,                            // Index of basis function of interest
+				      int footprint                         // Half-size of stamp
     )
 {
@@ -674,5 +669,5 @@
           if (index < kernels->inner) {
               // Photometric scaling is already built in to the precalculated kernel
-              return convolveStampISIS(image, kernels, index, footprint);
+              return convolveStampPreCalc(image, kernels, index, footprint);
           }
           // Using delta function
@@ -683,13 +678,10 @@
           return convolved;
       }
-      case PM_SUBTRACTION_KERNEL_ISIS: {
-          return convolveStampISIS(image, kernels, index, footprint);
-      }
-      case PM_SUBTRACTION_KERNEL_HERM: {
-          return convolveStampISIS(image, kernels, index, footprint);
-      }
+      case PM_SUBTRACTION_KERNEL_ISIS: 
+      case PM_SUBTRACTION_KERNEL_ISIS_RADIAL: 
+      case PM_SUBTRACTION_KERNEL_HERM:
       case PM_SUBTRACTION_KERNEL_DECONV_HERM: {
-          return convolveStampISIS(image, kernels, index, footprint);
-      }
+	    return convolveStampPreCalc(image, kernels, index, footprint);
+	}
       case PM_SUBTRACTION_KERNEL_RINGS: {
           psKernel *convolved = psKernelAlloc(-footprint, footprint, -footprint, footprint); // Convolved image
